@@ -1,5 +1,5 @@
 import json
-import importlib
+import logging
 
 from google.auth import jwt
 from google.cloud import pubsub_v1
@@ -9,13 +9,34 @@ from django.conf import settings
 from django.core.management import BaseCommand, CommandError
 from django.utils import autoreload
 
-from shopify_app.utils import get_function_from_string
+from ...utils import (
+    get_function_from_string, get_shop, webhook_request_is_valid
+)
+
+logger = logging.getLogger(__name__)
 
 
 def pubsub_callback(message):
+
     callback_path = settings.SHOPIFY_WEBHOOK_CALLBACK
-    func = get_function_from_string(callback_path)
-    func(message)
+
+    try:
+        shop = get_shop(message.attributes['X-Shopify-Shop-Domain'])
+        hmac = message.attributes['X-Shopify-Hmac-SHA256']
+
+        if webhook_request_is_valid(shop, hmac, message.data):
+
+            data = json.loads(message.data.decode('utf-8'))
+            webhook_topic = message.attributes['X-Shopify-Topic']
+            func = get_function_from_string(callback_path)
+            attributes = {
+                "api_version": message.attributes['X-Shopify-API-Version'],
+            }
+            func(shop, webhook_topic, data, attributes=attributes)
+
+    except Exception as e:
+        logger.error(str(e))
+
     message.ack()
 
 
