@@ -1,3 +1,4 @@
+import json
 from django.views import View
 from django.urls import reverse
 from django.conf import settings
@@ -122,3 +123,26 @@ class MandatoryWebhooksView(APIView):
         func(shop, self.topic, request.data, attributes={})
 
         return Response(status=200)
+
+
+class WebhooksView(APIView):
+
+    def post(self, request, *args, **kwargs):
+        meta = request.META
+        shop = get_shop(meta['HTTP_X_SHOPIFY_SHOP_DOMAIN'])
+        hmac = meta['HTTP_X_SHOPIFY_HMAC_SHA256']
+        webhook_topic = meta['HTTP_X_SHOPIFY_TOPIC']
+        api_version = meta['HTTP_X_SHOPIFY_API_VERSION']
+        data = request.body
+
+        if webhook_request_is_valid(shop, hmac, data):
+            callback_path = settings.SHOPIFY_WEBHOOK_CALLBACK
+            data = json.loads(data.decode('utf-8'))
+            func = get_function_from_string(callback_path)
+            attributes = {
+                "api_version": api_version,
+            }
+            func(shop, webhook_topic, data, attributes=attributes)
+            return Response(status=200)
+        else:
+            raise WebhookAuthenticationFailed()
